@@ -1,4 +1,5 @@
 from .hooks import Hook, add, get_args_for_hook
+from typing import List
 
 
 def _get_base_hook(name: str, nargs: int) -> str:
@@ -7,4 +8,4 @@ def _get_base_hook(name: str, nargs: int) -> str:
 
 def install_base_hooks():
     for hook in Hook:
-        add(hook, _get_base_hook(hook.value, get_args_for_hook(hook)))
+        add(hook, _get_base_hook(hook.value, len(get_args_for_hook(hook))))
